/*
 *  DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *  Copyright (c) 1997-2011 Oracle and/or its affiliates. All rights reserved.
 *
 *  The contents of this file are subject to the terms of either the GNU
 *  General Public License Version 2 only ("GPL") or the Common Development
 *  and Distribution License("CDDL") (collectively, the "License").  You
 *  may not use this file except in compliance with the License.  You can
 *  obtain a copy of the License at
 *  https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 *  or packager/legal/LICENSE.txt.  See the License for the specific
 *  language governing permissions and limitations under the License.
 *
 *  When distributing the software, include this License Header Notice in each
 *  file and include the License file at packager/legal/LICENSE.txt.
 *
 *  GPL Classpath Exception:
 *  Oracle designates this particular file as subject to the "Classpath"
 *  exception as provided by Oracle in the GPL Version 2 section of the License
 *  file that accompanied this code.
 *
 *  Modifications:
 *  If applicable, add the following below the License Header, with the fields
 *  enclosed by brackets [] replaced by your own identifying information:
 *   "Portions Copyright [year] [name of copyright owner]"
 *
 *  Contributor(s):
 *  If you wish your version of this file to be governed by only the CDDL or
 *  only the GPL Version 2, indicate your decision by adding "[Contributor]
 *  elects to include this software in this distribution under the [CDDL or GPL
 *  Version 2] license."  If you don't indicate a single choice of license, a
 *  recipient has the option to distribute your version of this file under
 *  either the CDDL, the GPL Version 2 or to extend the choice of license to
 *  its licensees as provided above.  However, if you add GPL Version 2 code
 *  and therefore, elected the GPL Version 2 license, then the option applies
 *  only if the new code is made subject to such option by the copyright
 *  holder.
 */
package org.glassfish.samples.conference;

import java.io.Serializable;
import java.util.Map;
import javax.el.MethodExpression;
import javax.enterprise.context.RequestScoped;
import javax.faces.context.FacesContext;
import javax.inject.Inject;
import javax.inject.Named;
import org.primefaces.component.menuitem.MenuItem;
import org.primefaces.component.submenu.Submenu;
import org.primefaces.model.DefaultMenuModel;
import org.primefaces.model.MenuModel;

/**
 *
 * @author aleftik
 */
@Named
@RequestScoped
public class MenuBean implements Serializable {

    private MenuModel model = null;
    @Inject
    RegistrationController registrationController;

    public MenuBean() {
        model = new DefaultMenuModel();
        buildMenu();
    }

    private void buildMenu() {
        Submenu homeSub = new Submenu();
        homeSub.setIcon("ui-icon ui-icon-home");
        homeSub.setLabel("Home");
        MenuItem home = new MenuItem();
        home.setValue("Home");
        home.setIcon("ui-icon ui-icon-home");
        home.setUrl("/index.xhtml");
        homeSub.getChildren().add(home);
        model.addSubmenu(homeSub);

        MenuItem test = new MenuItem();
        test.setValue("Load");
        test.setIcon("ui-icon ui-icon-home");
        test.setUrl("/load.xhtml");
        homeSub.getChildren().add(test);
        model.addSubmenu(homeSub);

        Submenu tracksSub = new Submenu();
        tracksSub.setLabel("Tracks");
        tracksSub.setIcon("ui-icon");
        MenuItem showTracks = new MenuItem();
        showTracks.setValue("Show Tracks");
        showTracks.setUrl("/tracks.xhtml");
        tracksSub.getChildren().add(showTracks);
        model.addSubmenu(tracksSub);

        Submenu speakersSub = new Submenu();
        speakersSub.setLabel("Speakers");
        speakersSub.setIcon("ui-icon");
        MenuItem showSpeakers = new MenuItem();
        showSpeakers.setValue("Show Speakers");
        showSpeakers.setUrl("/speakers.xhtml");
        speakersSub.getChildren().add(showSpeakers);
        model.addSubmenu(speakersSub);

        Submenu sessionSub = new Submenu();
        sessionSub.setLabel("Sessions");
        sessionSub.setIcon("ui-icon");
        MenuItem showSessions = new MenuItem();
        showSessions.setValue("Show Sessions");
        showSessions.setUrl("/sessions.xhtml");
        sessionSub.getChildren().add(showSessions);
        model.addSubmenu(sessionSub);
        buildLoggedInMenu();
    }

    private void buildLoggedInMenu() {
        if (isLoggedIn()) {

            Submenu MyScheduleSub = new Submenu();
            MyScheduleSub.setLabel("My Schedule");
            MyScheduleSub.setIcon("ui-icon");

            MenuItem editSchedule = new MenuItem();
            editSchedule.setValue("Edit Schedule");
            editSchedule.setUrl("/myschedule.xhtml");
            MyScheduleSub.getChildren().add(editSchedule);
            model.addSubmenu(MyScheduleSub);

            Submenu MyProfileSub = new Submenu();
            MyProfileSub.setLabel("My Profile");
            MyProfileSub.setIcon("ui-icon");

            MenuItem editProfile = new MenuItem();
            editProfile.setValue("Edit Profile");
            editProfile.setUrl("/myprofile.xhtml");
            MyProfileSub.getChildren().add(editProfile);

            MenuItem logout = new MenuItem();
            logout.setValue("Logout");
            logout.setAjax(false);
            MethodExpression logoutME = FacesContext.getCurrentInstance().getApplication().getExpressionFactory().
                    createMethodExpression(FacesContext.getCurrentInstance().getELContext(), "#{registrationController.logout}", null,
                    new Class<?>[0]);
            logout.setActionExpression(logoutME);

            MyProfileSub.getChildren().add(logout);
            model.addSubmenu(MyProfileSub);
        } else {

            Submenu loginSub = new Submenu();
            loginSub.setLabel("Register/Login");
            loginSub.setIcon("ui-icon");
            MenuItem login = new MenuItem();
            login.setValue("Login");
            login.setUrl("/login.xhtml");
            loginSub.getChildren().add(login);
            model.addSubmenu(loginSub);

            Submenu registerSub = new Submenu();
            registerSub.setLabel("Register");
            registerSub.setIcon("ui-icon");
            MenuItem register = new MenuItem();
            register.setValue("Register");
            register.setUrl("/register.xhtml");
            loginSub.getChildren().add(register);
            model.addSubmenu(loginSub);
        }
    }

    private boolean isLoggedIn() {
        RegistrationController controller = FacesContext.getCurrentInstance().getApplication()
                .evaluateExpressionGet(FacesContext.getCurrentInstance(), "#{registrationController}", RegistrationController.class);
        if (controller == null) {
            return false;
        }
        return controller.getIsLoggedIn();
    }

    public MenuModel getModel() {
        return this.model;
    }
}
