/*
 *  DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *  Copyright (c) 1997-2011 Oracle and/or its affiliates. All rights reserved.
 *
 *  The contents of this file are subject to the terms of either the GNU
 *  General Public License Version 2 only ("GPL") or the Common Development
 *  and Distribution License("CDDL") (collectively, the "License").  You
 *  may not use this file except in compliance with the License.  You can
 *  obtain a copy of the License at
 *  https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 *  or packager/legal/LICENSE.txt.  See the License for the specific
 *  language governing permissions and limitations under the License.
 *
 *  When distributing the software, include this License Header Notice in each
 *  file and include the License file at packager/legal/LICENSE.txt.
 *
 *  GPL Classpath Exception:
 *  Oracle designates this particular file as subject to the "Classpath"
 *  exception as provided by Oracle in the GPL Version 2 section of the License
 *  file that accompanied this code.
 *
 *  Modifications:
 *  If applicable, add the following below the License Header, with the fields
 *  enclosed by brackets [] replaced by your own identifying information:
 *   "Portions Copyright [year] [name of copyright owner]"
 *
 *  Contributor(s):
 *  If you wish your version of this file to be governed by only the CDDL or
 *  only the GPL Version 2, indicate your decision by adding "[Contributor]
 *  elects to include this software in this distribution under the [CDDL or GPL
 *  Version 2] license."  If you don't indicate a single choice of license, a
 *  recipient has the option to distribute your version of this file under
 *  either the CDDL, the GPL Version 2 or to extend the choice of license to
 *  its licensees as provided above.  However, if you add GPL Version 2 code
 *  and therefore, elected the GPL Version 2 license, then the option applies
 *  only if the new code is made subject to such option by the copyright
 *  holder.
 */
package org.glassfish.samples.conference;

import java.io.Serializable;
import java.util.List;
import java.util.Map;
import javax.ejb.EJB;
import javax.enterprise.context.SessionScoped;
import javax.faces.application.FacesMessage;
import javax.faces.context.FacesContext;
import javax.inject.Named;
import org.glassfish.samples.conference.entities.ConferenceAttendee;
import org.glassfish.samples.conference.entities.MySchedule;
import org.glassfish.samples.conference.entities.Sezzion;
import org.primefaces.event.CloseEvent;
import org.primefaces.event.SelectEvent;
import org.primefaces.event.UnselectEvent;

/**
 *
 * @author aleftik
 */
@Named("myScheduleController")
@SessionScoped
public class MyScheduleController implements Serializable {

    @EJB
    private MyScheduleBean scheduleRepository;
    private Sezzion selectedSezzion;
    private Sezzion deletedSezzion;

    /** Creates a new instance of MyScheduleController */
    public MyScheduleController() {
    }

    public void onRowSelect(SelectEvent event) {
        setSelectedSezzion((Sezzion) event.getObject());
    }

    public void onRowUnselect(UnselectEvent event) {
    }

    public void onRowSelectRemove(SelectEvent event) {
        Sezzion sessionToRemove = (Sezzion) event.getObject();
        setDeletedSelection(sessionToRemove);
    }

    private void updateSchedule(ConferenceAttendee attendee) {
        scheduleRepository.updateSchedule(attendee);
    }

    private ConferenceAttendee getAttendee() {
        RegistrationController controller = FacesContext.getCurrentInstance().getApplication()
                .evaluateExpressionGet(FacesContext.getCurrentInstance(), "#{registrationController}", RegistrationController.class);   
        ConferenceAttendee attendee = controller.getAttendee();
        return attendee;
    }

    public Sezzion getDeletedSelection() {
        return deletedSezzion;
    }

    public void setDeletedSelection(Sezzion deletedSezzion) {
        this.deletedSezzion = deletedSezzion;
    }

    public Sezzion getSelectedSezzion() {
        return selectedSezzion;
    }

    public void setSelectedSezzion(Sezzion selectedSezzion) {
        this.selectedSezzion = selectedSezzion;
    }

    public String onClose(CloseEvent event) {
        return "myschedule";
    }

    public void onAdd() {
        ConferenceAttendee attendee = getAttendee();
        MySchedule schedule = attendee.getSchedule();
        String message = checkForDuplicate(attendee, getSelectedSezzion());
        if (message == null) {
            schedule.addSezzion(getSelectedSezzion());
            updateSchedule(attendee);
            message = "Session " + getSelectedSezzion().getTitle() + " added to your schedule!";
        }
        FacesMessage msg = new FacesMessage(message);
        FacesContext.getCurrentInstance().addMessage(null, msg);
    }

    public void onRemove() {
        ConferenceAttendee attendee = getAttendee();
        MySchedule schedule = attendee.getSchedule();
        schedule.removeSession(getDeletedSelection());
        updateSchedule(attendee);

        FacesMessage msg = new FacesMessage("Session " + getDeletedSelection().getTitle() + " removed from your schedule!");
        FacesContext.getCurrentInstance().addMessage(null, msg);
    }

    private String checkForDuplicate(ConferenceAttendee attendee, Sezzion selectedSezzion) {
        if (selectedSezzion.getId() == null) return "Nothing Selected";
        if (attendee !=null) {
            if(attendee.getSchedule() != null) {
                MySchedule schedule = attendee.getSchedule();
                List<Sezzion> sessions = schedule.getSezzions();
                for (Sezzion session: sessions) {
                    
                    if (session.getId().equals(selectedSezzion.getId())) {
                        return "Duplicate Nothing Added!";
                    }
                }
                return null;
            }
        }
        return "Nothing Selected";
    }
}
