/*
 *  DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *  Copyright (c) 1997-2011 Oracle and/or its affiliates. All rights reserved.
 *
 *  The contents of this file are subject to the terms of either the GNU
 *  General Public License Version 2 only ("GPL") or the Common Development
 *  and Distribution License("CDDL") (collectively, the "License").  You
 *  may not use this file except in compliance with the License.  You can
 *  obtain a copy of the License at
 *  https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 *  or packager/legal/LICENSE.txt.  See the License for the specific
 *  language governing permissions and limitations under the License.
 *
 *  When distributing the software, include this License Header Notice in each
 *  file and include the License file at packager/legal/LICENSE.txt.
 *
 *  GPL Classpath Exception:
 *  Oracle designates this particular file as subject to the "Classpath"
 *  exception as provided by Oracle in the GPL Version 2 section of the License
 *  file that accompanied this code.
 *
 *  Modifications:
 *  If applicable, add the following below the License Header, with the fields
 *  enclosed by brackets [] replaced by your own identifying information:
 *   "Portions Copyright [year] [name of copyright owner]"
 *
 *  Contributor(s):
 *  If you wish your version of this file to be governed by only the CDDL or
 *  only the GPL Version 2, indicate your decision by adding "[Contributor]
 *  elects to include this software in this distribution under the [CDDL or GPL
 *  Version 2] license."  If you don't indicate a single choice of license, a
 *  recipient has the option to distribute your version of this file under
 *  either the CDDL, the GPL Version 2 or to extend the choice of license to
 *  its licensees as provided above.  However, if you add GPL Version 2 code
 *  and therefore, elected the GPL Version 2 license, then the option applies
 *  only if the new code is made subject to such option by the copyright
 *  holder.
 */
package org.glassfish.samples.conference;

import java.io.Serializable;
import javax.annotation.Resource;
import javax.ejb.Stateless;
import javax.ejb.LocalBean;
import javax.ejb.SessionContext;
import javax.ejb.TransactionAttribute;
import javax.ejb.TransactionAttributeType;
import javax.persistence.EntityManager;
import javax.persistence.NoResultException;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;
import javax.validation.ConstraintViolationException;
import org.glassfish.samples.conference.entities.ConferenceAttendee;

/**
 *
 * @author aleftik
 */
@Stateless
@LocalBean
public class RegistrationBean implements Serializable {

    @PersistenceContext(name = "ConferencePlannerPU")
    private EntityManager em;
    @Resource
    SessionContext ctx;

    public ConferenceAttendee findByUserName(String username) {
        Query q = em.createNamedQuery("ConferenceAttendee.findByUsername");
        q.setParameter("username", username.toUpperCase());
        try {
            return (ConferenceAttendee) q.getSingleResult();
        } catch (NoResultException nre) {
        }
        return null;
    }

    @TransactionAttribute(TransactionAttributeType.SUPPORTS)
    public boolean login(ConferenceAttendee attendee, String password) {
        boolean authed = false;
        if (attendee != null) {
            if (password.equals(attendee.getPassword())) {
                authed = true;
            }
        }
        return authed;
    }

    @TransactionAttribute(TransactionAttributeType.REQUIRED)
    public ConstraintViolationException regsiter(ConferenceAttendee attendee) {
        try {
            em.persist(attendee);
        } catch (ConstraintViolationException ve) {
            ctx.setRollbackOnly();
            return ve;
        }
        return null;
    }

    @TransactionAttribute(TransactionAttributeType.SUPPORTS)
    public boolean doesUsernameExist(String username) {
        ConferenceAttendee attendee = findByUserName(username);
        if (attendee != null) {
            return true;
        }
        return false;
    }

    @TransactionAttribute(TransactionAttributeType.REQUIRED)
    public ConstraintViolationException updateProfile(ConferenceAttendee attendee) {
        try {
            em.merge(attendee);
        } catch (ConstraintViolationException ve) {
            ctx.setRollbackOnly();
            return ve;
        }
        return null;
    }
}
