/*
 *  DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *  Copyright (c) 1997-2011 Oracle and/or its affiliates. All rights reserved.
 *
 *  The contents of this file are subject to the terms of either the GNU
 *  General Public License Version 2 only ("GPL") or the Common Development
 *  and Distribution License("CDDL") (collectively, the "License").  You
 *  may not use this file except in compliance with the License.  You can
 *  obtain a copy of the License at
 *  https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 *  or packager/legal/LICENSE.txt.  See the License for the specific
 *  language governing permissions and limitations under the License.
 *
 *  When distributing the software, include this License Header Notice in each
 *  file and include the License file at packager/legal/LICENSE.txt.
 *
 *  GPL Classpath Exception:
 *  Oracle designates this particular file as subject to the "Classpath"
 *  exception as provided by Oracle in the GPL Version 2 section of the License
 *  file that accompanied this code.
 *
 *  Modifications:
 *  If applicable, add the following below the License Header, with the fields
 *  enclosed by brackets [] replaced by your own identifying information:
 *   "Portions Copyright [year] [name of copyright owner]"
 *
 *  Contributor(s):
 *  If you wish your version of this file to be governed by only the CDDL or
 *  only the GPL Version 2, indicate your decision by adding "[Contributor]
 *  elects to include this software in this distribution under the [CDDL or GPL
 *  Version 2] license."  If you don't indicate a single choice of license, a
 *  recipient has the option to distribute your version of this file under
 *  either the CDDL, the GPL Version 2 or to extend the choice of license to
 *  its licensees as provided above.  However, if you add GPL Version 2 code
 *  and therefore, elected the GPL Version 2 license, then the option applies
 *  only if the new code is made subject to such option by the copyright
 *  holder.
 */
package org.glassfish.samples.conference;

import java.io.Serializable;
import javax.ejb.EJB;
import javax.enterprise.context.SessionScoped;
import javax.faces.application.FacesMessage;
import javax.faces.context.FacesContext;
import javax.faces.event.ActionEvent;
import javax.inject.Named;
import javax.servlet.http.HttpSession;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import org.glassfish.samples.conference.entities.ConferenceAttendee;

/**
 *
 * @author Adam Leftik
 */
@Named("registrationController")
@SessionScoped
public class RegistrationController implements Serializable {

    @EJB
    private RegistrationBean registrationRepository;
    private ConferenceAttendee attendee;
    private boolean loggedIn = false;

    /** Creates a new instance of RegistrationController */
    public RegistrationController() {
        attendee = new ConferenceAttendee();
    }

    public ConferenceAttendee getAttendee() {
        return attendee;
    }

    public void setAttendee(ConferenceAttendee attendee) {
        this.attendee = attendee;
    }

    public boolean getIsLoggedIn() {
        return loggedIn;
    }

    private void setLoggedIn(boolean loggedIn) {
        this.loggedIn = loggedIn;
    }

    public void register(ActionEvent actionEvent) {
        ConstraintViolationException result = registrationRepository.regsiter(getAttendee());
        if (result == null) {
            FacesContext.getCurrentInstance().addMessage(null, new FacesMessage("Welcome " + getAttendee().getFirstName() + " " + getAttendee().getLastName() + "!"));
            setLoggedIn(true);
        } else {
            for (ConstraintViolation error : result.getConstraintViolations()) {
                FacesContext.getCurrentInstance().addMessage(null, new FacesMessage("Error: " + error.getMessage() + "!"));
            }
        }
    }

    public String login() {
        String username = getAttendee().getUsername();
        String password = getAttendee().getPassword();
        if ((username != null) && (!"".equals(username)) && (password != null) && (!"".equals(password))) {
            attendee = registrationRepository.findByUserName(username);
            boolean authed = registrationRepository.login(attendee, password);
            
            if (authed) {
                setLoggedIn(true);
                return "sessions";
            } else {
                attendee = new ConferenceAttendee();
                FacesContext.getCurrentInstance().addMessage(null, new FacesMessage("Incorrect username and/or password."));
            }
        } else {
            attendee = new ConferenceAttendee();
            FacesContext.getCurrentInstance().addMessage(null, new FacesMessage("You need to enter a username and password to login"));
        }

        return "login";
    }

    public String logout() {
        HttpSession session = (HttpSession) FacesContext.getCurrentInstance().getExternalContext().getSession(false);
        session.invalidate();
        setLoggedIn(false);
        return "index";
    }

    public void updateProfile() {
        ConstraintViolationException result = registrationRepository.updateProfile(attendee);
        if (result == null) {
            FacesContext.getCurrentInstance().addMessage(null, new FacesMessage("Profile Updated for:  " + getAttendee().getFirstName() + " " + getAttendee().getLastName() + "!"));
            setLoggedIn(true);
        } else {
            for (ConstraintViolation error : result.getConstraintViolations()) {
                FacesContext.getCurrentInstance().addMessage(null, new FacesMessage("Error: " + error.getMessage() + "!"));
            }
        }
    }

    public void usernameUpdate() {
        String username = getAttendee().getUsername();
        if ((username != null) && (!"".equals(username))) {
            boolean inUse = registrationRepository.doesUsernameExist(username);
            if (inUse) {
                FacesContext.getCurrentInstance().addMessage(null, new FacesMessage("Sorry the username " + getAttendee().getUsername() + " is already taken!"));
                setLoggedIn(true);
            }
        }
    }
}
