/*
 *  DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *  Copyright (c) 1997-2011 Oracle and/or its affiliates. All rights reserved.
 *
 *  The contents of this file are subject to the terms of either the GNU
 *  General Public License Version 2 only ("GPL") or the Common Development
 *  and Distribution License("CDDL") (collectively, the "License").  You
 *  may not use this file except in compliance with the License.  You can
 *  obtain a copy of the License at
 *  https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 *  or packager/legal/LICENSE.txt.  See the License for the specific
 *  language governing permissions and limitations under the License.
 *
 *  When distributing the software, include this License Header Notice in each
 *  file and include the License file at packager/legal/LICENSE.txt.
 *
 *  GPL Classpath Exception:
 *  Oracle designates this particular file as subject to the "Classpath"
 *  exception as provided by Oracle in the GPL Version 2 section of the License
 *  file that accompanied this code.
 *
 *  Modifications:
 *  If applicable, add the following below the License Header, with the fields
 *  enclosed by brackets [] replaced by your own identifying information:
 *   "Portions Copyright [year] [name of copyright owner]"
 *
 *  Contributor(s):
 *  If you wish your version of this file to be governed by only the CDDL or
 *  only the GPL Version 2, indicate your decision by adding "[Contributor]
 *  elects to include this software in this distribution under the [CDDL or GPL
 *  Version 2] license."  If you don't indicate a single choice of license, a
 *  recipient has the option to distribute your version of this file under
 *  either the CDDL, the GPL Version 2 or to extend the choice of license to
 *  its licensees as provided above.  However, if you add GPL Version 2 code
 *  and therefore, elected the GPL Version 2 license, then the option applies
 *  only if the new code is made subject to such option by the copyright
 *  holder.
 */
package org.glassfish.samples.conference.entities;


import java.io.Serializable;
import javax.inject.Named;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToOne;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Pattern;
import javax.validation.constraints.Size;
import javax.xml.bind.annotation.XmlRootElement;

/**
 *
 * @author aleftik
 */
@Entity
@XmlRootElement
@NamedQueries (value={
    @NamedQuery(name="ConferenceAttendee.findByUsername",query="SELECT c FROM ConferenceAttendee c WHERE UPPER(c.username) LIKE :username")
})
@Named
public class ConferenceAttendee implements Serializable {
    
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private Long id;
    
    @Column
    @NotNull(message="{username.required}")
    @Size(min = 3, max = 255, message="{username.length}")
    private String username;
    
    @Column
    @NotNull(message="{password.required}")
    @Size(min = 1, max = 255,message="{password.length}")
    private String password;
    
    @Column
    @Pattern(regexp="[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\\."
        +"[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*"
        +"@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?",
             message="{email.invalid}")
    @Size(min = 1, max = 255,message="{email.length}")
    private String emailAddress;
    
    @Column
    @NotNull(message="{firstName.required}")
    @Size(min = 1, max = 255,message="{firstName.length}")
    private String firstName;
    
    @Column
    @NotNull(message="{lastName.required}")
    @Size(min = 1, max = 255,message="{lastName.length}")
    private String lastName;
    
    @Column
    @NotNull(message="{salutation.required}")
    @Size(min = 2, max = 3,message="{salutation.length}")
    private String salutation;
    
    @Column
    @NotNull(message="{title.required}")
    @Size(min=1, max=255, message="{title.length}")
    private String title;
    
    @Column
    @NotNull(message="{organization.required}")
    @Size(min=1, max=255,message="{organization.length}")
    private String organization;
    
    @Column
    @NotNull(message="{address1.required}")
    @Size(min=1, max=255, message="{address1.length}")
    private String address1;
    
    @Column
    @Size(max=255, message="{address2.length}")
    private String address2;
    
    @Column
    @NotNull(message="{city.required}")
    @Size(min=1, max=255,message="{city.length}")
    private String city;
    
    @Column(name="ADDRESSSTATE")
    @NotNull(message="{state.required}")
    @Size(min=2, max=2,message="{state.length}")
    private String state;
    
    @Column
    @NotNull(message="{zip.required}")
    @Pattern(regexp="\\d{5}",message="{zip.length}")
    private String zip;
    
    @OneToOne(cascade= CascadeType.ALL, fetch= FetchType.LAZY)
    //@JoinColumn(name="ID",nullable=true,updatable=false)
    private MySchedule schedule;
    
    public ConferenceAttendee() {
    }

    public String getAddress1() {
        return address1;
    }

    public void setAddress1(String address1) {
        this.address1 = address1;
    }

    public String getAddress2() {
        return address2;
    }

    public void setAddress2(String address2) {
        this.address2 = address2;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }
    
    public String getEmailAddress() {
        return emailAddress;
    }

    public void setEmailAddress(String emailAddress) {
        this.emailAddress = emailAddress;
    }

    public String getFirstName() {
        return firstName;
    }

    public void setFirstName(String firstName) {
        this.firstName = firstName;
    }

    public String getLastName() {
        return lastName;
    }

    public void setLastName(String lastName) {
        this.lastName = lastName;
    }

    public String getOrganization() {
        return organization;
    }

    public void setOrganization(String organization) {
        this.organization = organization;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }
    
    

    public String getSalutation() {
        return salutation;
    }

    public void setSalutation(String salutation) {
        this.salutation = salutation;
    }

    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public String getZip() {
        return zip;
    }

    public void setZip(String zip) {
        this.zip = zip;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public synchronized MySchedule getSchedule() {
        if (schedule == null) {
            setSchedule(new MySchedule());
        }
        return schedule;
    }

    public void setSchedule(MySchedule schedule) {
        this.schedule = schedule;
    }

    
    @Override
    public int hashCode() {
        int hash = 0;
        hash += (id != null ? id.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        if (!(object instanceof ConferenceAttendee)) {
            return false;
        }
        ConferenceAttendee other = (ConferenceAttendee) object;
        if ((this.id == null && other.id != null) || (this.id != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "org.glassfish.samples.conference.entities.ConferenceAttendee[ id=" + id + ", username=" + getUsername() + " ]";
    }
    
}
