    /*
 *  DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *  Copyright (c) 1997-2011 Oracle and/or its affiliates. All rights reserved.
 *
 *  The contents of this file are subject to the terms of either the GNU
 *  General Public License Version 2 only ("GPL") or the Common Development
 *  and Distribution License("CDDL") (collectively, the "License").  You
 *  may not use this file except in compliance with the License.  You can
 *  obtain a copy of the License at
 *  https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 *  or packager/legal/LICENSE.txt.  See the License for the specific
 *  language governing permissions and limitations under the License.
 *
 *  When distributing the software, include this License Header Notice in each
 *  file and include the License file at packager/legal/LICENSE.txt.
 *
 *  GPL Classpath Exception:
 *  Oracle designates this particular file as subject to the "Classpath"
 *  exception as provided by Oracle in the GPL Version 2 section of the License
 *  file that accompanied this code.
 *
 *  Modifications:
 *  If applicable, add the following below the License Header, with the fields
 *  enclosed by brackets [] replaced by your own identifying information:
 *   "Portions Copyright [year] [name of copyright owner]"
 *
 *  Contributor(s):
 *  If you wish your version of this file to be governed by only the CDDL or
 *  only the GPL Version 2, indicate your decision by adding "[Contributor]
 *  elects to include this software in this distribution under the [CDDL or GPL
 *  Version 2] license."  If you don't indicate a single choice of license, a
 *  recipient has the option to distribute your version of this file under
 *  either the CDDL, the GPL Version 2 or to extend the choice of license to
 *  its licensees as provided above.  However, if you add GPL Version 2 code
 *  and therefore, elected the GPL Version 2 license, then the option applies
 *  only if the new code is made subject to such option by the copyright
 *  holder.
 */
package org.glassfish.samples.conference.entities;

import java.io.Serializable;
import java.util.List;
import javax.persistence.Column;
import javax.persistence.ElementCollection;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.ManyToMany;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;
import javax.validation.constraints.NotNull;
import javax.xml.bind.annotation.XmlRootElement;

/**
 * @author arun
 */
@Entity
@Table(name = "SEZZION")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "Sezzion.findAllSezzions", query = "SELECT s FROM Sezzion s"),
    @NamedQuery(name = "Sezzion.findSezzionById", query = "SELECT s FROM Sezzion s where s.id = :id"),
    @NamedQuery(name = "Sezzion.findAllTracks", query = "SELECT DISTINCT s.track FROM Sezzion s"),
    @NamedQuery(name = "Sezzion.findAllType", query = "SELECT DISTINCT s.type FROM Sezzion s"),
    @NamedQuery(name = "Sezzion.findAllTypes", query = "SELECT DISTINCT s.type FROM Sezzion s"),
    @NamedQuery(name = "Sezzion.findAllSezzionByTrack", query = "SELECT s FROM Sezzion s where s.track = :track")
})
public class Sezzion implements Serializable {
    private static final long serialVersionUID = 1L;
    @Id 
    @NotNull
    @Column(name="id")
    private String id;
    
    @Column(name="title", length=100)
    private String title;
    
    @Column(name="abztract", length=1000)
    private String abztract;
    
    @Column(name="type", length=100)
    private String type;
    
    @Column(name="track", length=100)
    private String track;
    
    @Column(name="status", length=50)
    private String status;
    
    @Column(name="sezzionLevel", length=50)
    private String sezzionLevel;
    
    @Column(name="sezzionLength", length=3)
    private int sezzionLength;
    
    @ElementCollection
    List<SezzionTime> sezzionTimes;
    
    @Column(name="optionalTrack", length=80)
    private String optionalTrack;
    
    @Column(name="primaryTrack", length=80)
    private String primaryTrack;
    
    @Column(name="stream", length=25)
    private String stream;
    
    @ManyToMany
    List<Speaker> speakers;
    
    public Sezzion() { }

    public String getAbztract() {
        return abztract;
    }

    public void setAbztract(String abztract) {
        this.abztract = abztract;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getOptionalTrack() {
        return optionalTrack;
    }

    public void setOptionalTrack(String optionalTrack) {
        this.optionalTrack = optionalTrack;
    }

    public String getPrimaryTrack() {
        return primaryTrack;
    }

    public void setPrimaryTrack(String primaryTrack) {
        this.primaryTrack = primaryTrack;
    }

    public String getSezzionLevel() {
        return sezzionLevel;
    }

    public void setSezzionLevel(String sezzionLevel) {
        this.sezzionLevel = sezzionLevel;
    }

    public List<SezzionTime> getSezzionTime() {
        return sezzionTimes;
    }

    public int getSezzionLength() {
        return sezzionLength;
    }

    public void setSezzionLength(int sezzionlength) {
        this.sezzionLength = sezzionlength;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getStream() {
        return stream;
    }

    public void setStream(String stream) {
        this.stream = stream;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getTrack() {
        return track;
    }

    public void setTrack(String track) {
        this.track = track;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public List<Speaker> getSpeakers() {
        return speakers;
    }
    
    
    @Override
    public int hashCode() {
        int hash = 0;
        hash += (id != null ? id.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof Sezzion)) {
            return false;
        }
        Sezzion other = (Sezzion) object;
        if ((this.id == null && other.id != null) || (this.id != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        String result = id + title;
        
        for (Speaker s : speakers) {
            result.concat(s.getSpeakerfirstname() + ", ");
        }
        
        return result;
    }
    
}
