/*
 *  DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *  Copyright (c) 1997-2011 Oracle and/or its affiliates. All rights reserved.
 *
 *  The contents of this file are subject to the terms of either the GNU
 *  General Public License Version 2 only ("GPL") or the Common Development
 *  and Distribution License("CDDL") (collectively, the "License").  You
 *  may not use this file except in compliance with the License.  You can
 *  obtain a copy of the License at
 *  https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 *  or packager/legal/LICENSE.txt.  See the License for the specific
 *  language governing permissions and limitations under the License.
 *
 *  When distributing the software, include this License Header Notice in each
 *  file and include the License file at packager/legal/LICENSE.txt.
 *
 *  GPL Classpath Exception:
 *  Oracle designates this particular file as subject to the "Classpath"
 *  exception as provided by Oracle in the GPL Version 2 section of the License
 *  file that accompanied this code.
 *
 *  Modifications:
 *  If applicable, add the following below the License Header, with the fields
 *  enclosed by brackets [] replaced by your own identifying information:
 *   "Portions Copyright [year] [name of copyright owner]"
 *
 *  Contributor(s):
 *  If you wish your version of this file to be governed by only the CDDL or
 *  only the GPL Version 2, indicate your decision by adding "[Contributor]
 *  elects to include this software in this distribution under the [CDDL or GPL
 *  Version 2] license."  If you don't indicate a single choice of license, a
 *  recipient has the option to distribute your version of this file under
 *  either the CDDL, the GPL Version 2 or to extend the choice of license to
 *  its licensees as provided above.  However, if you add GPL Version 2 code
 *  and therefore, elected the GPL Version 2 license, then the option applies
 *  only if the new code is made subject to such option by the copyright
 *  holder.
 */
package org.glassfish.samples.conference.entities;

import java.io.Serializable;
import java.util.List;
import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.ManyToMany;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import javax.xml.bind.annotation.XmlRootElement;

/**
 * @author Arun Gupta
 */
@Entity
@Table(name = "SPEAKER")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "Speaker.findAll", query = "SELECT s FROM Speaker s"),
    @NamedQuery(name = "Speaker.findBySpeakerid", query = "SELECT s FROM Speaker s WHERE s.speakerid = :speakerid"),
    @NamedQuery(name = "Speaker.findBySpeakercompany", query = "SELECT s FROM Speaker s WHERE s.speakercompany = :speakercompany"),
    @NamedQuery(name = "Speaker.findBySpeakerfirstname", query = "SELECT s FROM Speaker s WHERE s.speakerfirstname = :speakerfirstname"),
    @NamedQuery(name = "Speaker.findBySpeakerjobtitle", query = "SELECT s FROM Speaker s WHERE s.speakerjobtitle = :speakerjobtitle"),
    @NamedQuery(name = "Speaker.findBySpeakerlastname", query = "SELECT s FROM Speaker s WHERE s.speakerlastname = :speakerlastname")})
public class Speaker implements Serializable {
    private static final long serialVersionUID = 1L;
    @Id
    @Basic(optional = false)
    @NotNull
    @Size(min = 1, max = 255)
    @Column(name = "id")
    private String speakerid;
    
    @Size(max = 255)
    @Column(name = "company")
    private String speakercompany;
    
    @Size(max = 255)
    @Column(name = "firstName")
    private String speakerfirstname;
    
    @Size(max = 255)
    @Column(name = "jobTitle")
    private String speakerjobtitle;
    
    @Size(max = 255)
    @Column(name = "lastName")
    private String speakerlastname;
    
    @ManyToMany(mappedBy="speakers")
    List<Sezzion> sessions;

    public Speaker() {
    }

    public Speaker(String speakerid) {
        this.speakerid = speakerid;
    }

    public String getSpeakerid() {
        return speakerid;
    }

    public void setSpeakerid(String speakerid) {
        this.speakerid = speakerid;
    }

    public String getSpeakercompany() {
        return speakercompany;
    }

    public void setSpeakercompany(String speakercompany) {
        this.speakercompany = speakercompany;
    }

    public String getSpeakerfirstname() {
        return speakerfirstname;
    }

    public void setSpeakerfirstname(String speakerfirstname) {
        this.speakerfirstname = speakerfirstname;
    }

    public String getSpeakerjobtitle() {
        return speakerjobtitle;
    }

    public void setSpeakerjobtitle(String speakerjobtitle) {
        this.speakerjobtitle = speakerjobtitle;
    }

    public String getSpeakerlastname() {
        return speakerlastname;
    }

    public void setSpeakerlastname(String speakerlastname) {
        this.speakerlastname = speakerlastname;
    }

    public List<Sezzion> getSessions() {
        return sessions;
    }
    
    @Override
    public int hashCode() {
        int hash = 0;
        hash += (speakerid != null ? speakerid.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof Speaker)) {
            return false;
        }
        Speaker other = (Speaker) object;
        if ((this.speakerid == null && other.speakerid != null) || (this.speakerid != null && !this.speakerid.equals(other.speakerid))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "org.glassfish.samples.conference.entities.Speaker[ speakerid=" + speakerid + " ]";
    }
    
}
